@@ -26,12 +26,12 @@
 
 #include <cstddef>
 #include <cstdint>
-#include <string>
 #include <vector>
 
 #include "image.h"
 
 class StreamBuf;
+class StreamFile;
 
 namespace Compression
 {
@@ -44,15 +44,14 @@ namespace Compression
     // zero, the size of the decompressed data will be determined automatically.
     std::vector<uint8_t> decompressData( const uint8_t * src, const size_t srcSize, size_t realSize = 0 );
 
-    // Reads & unzips the zipped chunk from the specified file at the specified offset and appends
-    // it to the end of the buffer. The current read position of the buffer does not change. Returns
-    // true on success or false on error.
-    bool readFile( StreamBuf & output, const std::string & fn, const size_t offset = 0 );
+    // Reads & unzips the zipped chunk from the specified file stream and appends
+    // it to the end of the buffer. Returns true on success or false on error.
+    bool readFromFileStream( StreamFile & fileStream, StreamBuf & output );
 
-    // Zips the contents of the buffer from the current read position to the end of the buffer and
-    // writes (or appends) it to the specified file. The current read position of the buffer does
-    // not change. Returns true on success and false on error.
-    bool writeFile( StreamBuf & input, const std::string & fn, const bool append = false );
+    // Zips the contents of the buffer from the current read position to the end of the buffer and writes
+    // it to the specified file stream. The current read position of the buffer does not change. Returns
+    // true on success and false on error.
+    bool writeIntoFileStream( StreamFile & fileStream, StreamBuf & data );
 
     fheroes2::Image CreateImageFromZlib( int32_t width, int32_t height, const uint8_t * imageData, size_t imageSize, bool doubleLayer );
 }
