@@ -817,7 +817,7 @@ namespace
     {
         DEBUG_LOG( DBG_AI, DBG_INFO, hero.GetName() )
 
-        const Funds payment( Resource::GOLD, 1000 );
+        const Funds payment = PaymentConditions::getMagellansMapsPurchasePrice();
         Kingdom & kingdom = hero.GetKingdom();
 
         if ( !hero.isObjectTypeVisited( MP2::OBJ_MAGELLANS_MAPS, Visit::GLOBAL ) && kingdom.AllowPayment( payment ) ) {
@@ -1119,13 +1119,17 @@ namespace
         MapEvent * event_maps = world.GetMapEvent( Maps::GetPoint( dst_index ) );
 
         if ( event_maps && event_maps->isAllow( hero.GetColor() ) && event_maps->computer ) {
-            if ( event_maps->resources.GetValidItemsCount() )
+            if ( event_maps->resources.GetValidItemsCount() ) {
                 hero.GetKingdom().AddFundsResource( event_maps->resources );
-            if ( event_maps->artifact.isValid() )
-                hero.PickupArtifact( event_maps->artifact );
-            event_maps->SetVisited( hero.GetColor() );
+            }
 
-            if ( event_maps->cancel ) {
+            if ( event_maps->artifact.isValid() ) {
+                hero.PickupArtifact( event_maps->artifact );
+            }
+
+            event_maps->SetVisited();
+
+            if ( event_maps->isSingleTimeEvent ) {
                 hero.setObjectTypeUnderHero( MP2::OBJ_NONE );
                 world.RemoveMapObject( event_maps );
             }
@@ -1167,11 +1171,17 @@ namespace
         assert( hero.GetIndex() == dst_index || MP2::isNeedStayFront( objectType ) );
 
         if ( !AI::Get().isValidHeroObject( hero, dst_index, ( hero.GetIndex() == dst_index ) ) ) {
-            // If we can't step on this tile, then we shouldn't be here at all
-            assert( !MP2::isNeedStayFront( objectType ) );
+            if ( MP2::isNeedStayFront( objectType ) ) {
+                // If we can't step on this tile, then we shouldn't be here at all, but we can still end up here due to inaccuracies in the hero's strength assessment at
+                // the starting point of his path (for example, if the hero's starting point was in a castle, then the castle's bonuses could affect the assessment of his
+                // strength)
+                DEBUG_LOG( DBG_AI, DBG_INFO, hero.GetName() << " does not interact with the object and ignores it" )
+            }
+            else {
+                // We're just passing through here, don't mess with this object
+                DEBUG_LOG( DBG_AI, DBG_INFO, hero.GetName() << " passes through without interacting with the object" )
+            }
 
-            // We're just passing through here, don't mess with this object
-            DEBUG_LOG( DBG_AI, DBG_INFO, hero.GetName() << " passes through without interacting with the object" )
             return;
         }
 
@@ -1525,48 +1535,53 @@ namespace
     {
         DEBUG_LOG( DBG_AI, DBG_INFO, hero.GetName() )
 
+        if ( hero.IsFullBagArtifacts() ) {
+            return;
+        }
+
         Maps::Tiles & tile = world.GetTiles( dst_index );
 
-        if ( !hero.IsFullBagArtifacts() ) {
-            const Maps::ArtifactCaptureCondition condition = getArtifactCaptureCondition( tile );
-            const Artifact art = getArtifactFromTile( tile );
+        const Artifact art = getArtifactFromTile( tile );
+        if ( art.GetID() == Artifact::MAGIC_BOOK && hero.HaveSpellBook() ) {
+            return;
+        }
 
-            bool result = false;
+        const Maps::ArtifactCaptureCondition condition = getArtifactCaptureCondition( tile );
 
-            if ( condition == Maps::ArtifactCaptureCondition::PAY_2000_GOLD || condition == Maps::ArtifactCaptureCondition::PAY_2500_GOLD_AND_3_RESOURCES
-                 || condition == Maps::ArtifactCaptureCondition::PAY_3000_GOLD_AND_5_RESOURCES ) {
-                const Funds payment = getArtifactResourceRequirement( tile );
+        bool result = false;
 
-                if ( hero.GetKingdom().AllowPayment( payment ) ) {
-                    result = true;
-                    hero.GetKingdom().OddFundsResource( payment );
-                }
-            }
-            else if ( condition == Maps::ArtifactCaptureCondition::HAVE_WISDOM_SKILL || condition == Maps::ArtifactCaptureCondition::HAVE_LEADERSHIP_SKILL ) {
-                // TODO: do we need to check this condition?
+        if ( condition == Maps::ArtifactCaptureCondition::PAY_2000_GOLD || condition == Maps::ArtifactCaptureCondition::PAY_2500_GOLD_AND_3_RESOURCES
+             || condition == Maps::ArtifactCaptureCondition::PAY_3000_GOLD_AND_5_RESOURCES ) {
+            const Funds payment = getArtifactResourceRequirement( tile );
+
+            if ( hero.GetKingdom().AllowPayment( payment ) ) {
                 result = true;
+                hero.GetKingdom().OddFundsResource( payment );
             }
-            else if ( condition >= Maps::ArtifactCaptureCondition::FIGHT_50_ROGUES && condition <= Maps::ArtifactCaptureCondition::FIGHT_1_BONE_DRAGON ) {
-                Army army( tile );
+        }
+        else if ( condition == Maps::ArtifactCaptureCondition::HAVE_WISDOM_SKILL || condition == Maps::ArtifactCaptureCondition::HAVE_LEADERSHIP_SKILL ) {
+            // TODO: do we need to check this condition?
+            result = true;
+        }
+        else if ( condition >= Maps::ArtifactCaptureCondition::FIGHT_50_ROGUES && condition <= Maps::ArtifactCaptureCondition::FIGHT_1_BONE_DRAGON ) {
+            Army army( tile );
 
-                // new battle
-                Battle::Result res = Battle::Loader( hero.GetArmy(), army, dst_index );
-                if ( res.AttackerWins() ) {
-                    hero.IncreaseExperience( res.GetExperienceAttacker() );
-                    result = true;
-                }
-                else {
-                    AIBattleLose( hero, res, true );
-                }
+            Battle::Result res = Battle::Loader( hero.GetArmy(), army, dst_index );
+            if ( res.AttackerWins() ) {
+                hero.IncreaseExperience( res.GetExperienceAttacker() );
+                result = true;
             }
             else {
-                result = true;
+                AIBattleLose( hero, res, true );
             }
+        }
+        else {
+            result = true;
+        }
 
-            if ( result && hero.PickupArtifact( art ) ) {
-                removeObjectSprite( tile );
-                resetObjectInfoOnTile( tile );
-            }
+        if ( result && hero.PickupArtifact( art ) ) {
+            removeObjectSprite( tile );
+            resetObjectInfoOnTile( tile );
         }
     }
 
@@ -1733,7 +1748,7 @@ namespace AI
         const Maps::Tiles & tile = world.GetTiles( dst_index );
         const MP2::MapObjectType objectType = tile.GetObject( dst_index != hero.GetIndex() );
 
-        const bool isActionObject = MP2::isActionObject( objectType, hero.isShipMaster() );
+        const bool isActionObject = MP2::isInGameActionObject( objectType, hero.isShipMaster() );
         if ( isActionObject )
             hero.SetModes( Heroes::ACTION );
 
@@ -2049,6 +2064,12 @@ namespace AI
             }
 
             if ( hideAIMovements || !AIIsShowAnimationForHero( hero, colors ) ) {
+                // A hero might have been moving with visible animation for humans till he reaches the area
+                // where animation is not needed. This can be in the middle of movement between tiles.
+                // In this case it is important to reset animation sprite to make sure that the hero is
+                // ready for jump steps.
+                hero.resetHeroSprite();
+
                 hero.Move( true );
                 recenterNeeded = true;
 
