@@ -237,7 +237,7 @@ namespace
             // Rough estimate - if the hero is in the castle, then we sum up the power of the castle garrison with the power of the hero's army
             const double threat = castle ? castle->GetArmy().GetStrength() + hero->GetArmy().GetStrength() : hero->GetArmy().GetStrength();
 
-            return AI::EnemyArmy( tileIndex, hero, threat, hero->GetMaxMovePoints() );
+            return AI::EnemyArmy( tileIndex, hero->GetColor(), hero, threat, hero->GetMaxMovePoints() );
         }
 
         if ( object == MP2::OBJ_CASTLE ) {
@@ -260,7 +260,7 @@ namespace
             const double threat = castle->GetArmy().GetStrength();
 
             // 1500 is slightly more than a fresh hero's maximum move points hired in a castle.
-            return AI::EnemyArmy( tileIndex, nullptr, threat, 1500 );
+            return AI::EnemyArmy( tileIndex, castle->GetColor(), nullptr, threat, 1500 );
         }
 
         return {};
@@ -269,7 +269,7 @@ namespace
 
 namespace AI
 {
-    bool Normal::recruitHero( Castle & castle, bool buyArmy, bool underThreat )
+    bool Normal::recruitHero( Castle & castle, bool buyArmy )
     {
         Kingdom & kingdom = castle.GetKingdom();
         const Recruits & rec = kingdom.GetRecruits();
@@ -310,7 +310,6 @@ namespace AI
         }
 
         if ( buyArmy ) {
-            CastleTurn( castle, underThreat );
             reinforceHeroInCastle( *recruit, castle, kingdom.GetFunds() );
         }
         else {
@@ -481,12 +480,16 @@ namespace AI
     std::vector<AICastle> Normal::getSortedCastleList( const VecCastles & castles, const std::set<int> & castlesInDanger )
     {
         std::vector<AICastle> sortedCastleList;
+        sortedCastleList.reserve( castles.size() );
+
         for ( Castle * castle : castles ) {
-            if ( !castle )
+            if ( castle == nullptr ) {
                 continue;
+            }
 
             const int32_t castleIndex = castle->GetIndex();
             const uint32_t regionID = world.GetTiles( castleIndex ).GetRegion();
+
             sortedCastleList.emplace_back( castle, castlesInDanger.count( castleIndex ) > 0, _regions[regionID].safetyFactor, castle->getBuildingValue() );
         }
 
@@ -519,6 +522,12 @@ namespace AI
         // if no our heroes exist. So we are temporary removing them from the map.
         const TemporaryHeroEraser heroEraser( kingdom.GetHeroes() );
 
+        const AIWorldPathfinderStateRestorer pathfinderStateRestorer( _pathfinder );
+
+        // Use the "optimistic" pathfinder settings for enemy armies - minimal army advantage, minimal reserve of spell points
+        _pathfinder.setMinimalArmyStrengthAdvantage( ARMY_ADVANTAGE_DESPERATE );
+        _pathfinder.setSpellPointsReserveRatio( 0.0 );
+
         for ( const auto & [dummy, enemyArmy] : _enemyArmies ) {
             for ( const Castle * castle : kingdom.GetCastles() ) {
                 if ( castle == nullptr ) {
@@ -542,6 +551,12 @@ namespace AI
         // if no our heroes exist. So we are temporary removing them from the map.
         const TemporaryHeroEraser heroEraser( kingdom.GetHeroes() );
 
+        const AIWorldPathfinderStateRestorer pathfinderStateRestorer( _pathfinder );
+
+        // Use the "optimistic" pathfinder settings for enemy armies - minimal army advantage, minimal reserve of spell points
+        _pathfinder.setMinimalArmyStrengthAdvantage( ARMY_ADVANTAGE_DESPERATE );
+        _pathfinder.setSpellPointsReserveRatio( 0.0 );
+
         for ( const Castle * castle : kingdom.GetCastles() ) {
             if ( castle == nullptr ) {
                 // How is it even possible? Check the logic!
@@ -559,6 +574,12 @@ namespace AI
         // if no our heroes exist. So we are temporary removing them from the map.
         const TemporaryHeroEraser heroEraser( castle.GetKingdom().GetHeroes() );
 
+        const AIWorldPathfinderStateRestorer pathfinderStateRestorer( _pathfinder );
+
+        // Use the "optimistic" pathfinder settings for enemy armies - minimal army advantage, minimal reserve of spell points
+        _pathfinder.setMinimalArmyStrengthAdvantage( ARMY_ADVANTAGE_DESPERATE );
+        _pathfinder.setSpellPointsReserveRatio( 0.0 );
+
         for ( const auto & [dummy, enemyArmy] : _enemyArmies ) {
             updateIndividualPriorityForCastle( castle, enemyArmy );
         }
@@ -570,12 +591,13 @@ namespace AI
         const uint32_t threatDistanceLimit = 3000;
 
         const int32_t castleIndex = castle.GetIndex();
-        // skip precise distance check if army is too far to be a threat
-        if ( Maps::GetApproximateDistance( enemyArmy.index, castleIndex ) * Maps::Ground::roadPenalty > threatDistanceLimit ) {
+
+        // Skip precise distance check if army is too far to be a threat
+        if ( Maps::GetApproximateDistance( enemyArmy.index, castleIndex ) * Maps::Ground::fastestMovePenalty > threatDistanceLimit ) {
             return false;
         }
 
-        const uint32_t dist = _pathfinder.getDistance( enemyArmy.index, castleIndex, castle.GetColor(), enemyArmy.strength );
+        const uint32_t dist = _pathfinder.getDistance( enemyArmy.index, castleIndex, enemyArmy.color, enemyArmy.strength );
         if ( dist == 0 || dist >= threatDistanceLimit ) {
             return false;
         }
@@ -776,7 +798,7 @@ namespace AI
                 continue;
             }
 
-            if ( !MP2::isActionObject( objectType ) ) {
+            if ( !MP2::isInGameActionObject( objectType ) ) {
                 continue;
             }
 
@@ -902,6 +924,8 @@ namespace AI
         // Sync the list of castles (if new ones were captured during the turn)
         if ( castles.size() != sortedCastleList.size() ) {
             evaluateRegionSafety();
+
+            castlesInDanger = findCastlesInDanger( kingdom );
             sortedCastleList = getSortedCastleList( castles, castlesInDanger );
         }
 
@@ -928,13 +952,8 @@ namespace AI
     bool Normal::purchaseNewHeroes( const std::vector<AICastle> & sortedCastleList, const std::set<int> & castlesInDanger, const int32_t availableHeroCount,
                                     const bool moreTasksForHeroes )
     {
-        const bool slowEarlyGame = world.CountDay() < 5 && sortedCastleList.size() == 1;
-        int32_t heroLimit = world.w() / Maps::SMALL + 1;
-
-        if ( _personality == EXPLORER )
-            ++heroLimit;
-        if ( slowEarlyGame )
-            heroLimit = 2;
+        const bool isEarlyGameWithSingleCastle = world.CountDay() < 5 && sortedCastleList.size() == 1;
+        const int32_t heroLimit = isEarlyGameWithSingleCastle ? 2 : world.w() / Maps::SMALL + 2;
 
         if ( availableHeroCount >= heroLimit ) {
             return false;
@@ -977,7 +996,7 @@ namespace AI
         }
 
         // target found, buy hero
-        return recruitmentCastle && recruitHero( *recruitmentCastle, !slowEarlyGame, false );
+        return recruitmentCastle && recruitHero( *recruitmentCastle, !isEarlyGameWithSingleCastle );
     }
 
     void Normal::tradingPostVisitEvent( Kingdom & /*kingdom*/ )
