@@ -24,7 +24,6 @@
 #include "army.h"
 
 #include <algorithm>
-#include <array>
 #include <cassert>
 #include <cmath>
 #include <map>
@@ -239,17 +238,19 @@ Troops::~Troops()
     } );
 }
 
-void Troops::Assign( const Troop * it1, const Troop * it2 )
+void Troops::Assign( const Troop * itbeg, const Troop * itend )
 {
     Clean();
 
     iterator it = begin();
 
-    while ( it != end() && it1 != it2 ) {
-        if ( it1->isValid() )
-            ( *it )->Set( *it1 );
+    while ( it != end() && itbeg != itend ) {
+        if ( itbeg->isValid() ) {
+            ( *it )->Set( *itbeg );
+        }
+
         ++it;
-        ++it1;
+        ++itbeg;
     }
 }
 
@@ -281,10 +282,13 @@ void Troops::PushBack( const Monster & mons, uint32_t count )
 
 void Troops::PopBack()
 {
-    if ( !empty() ) {
-        delete back();
-        pop_back();
+    if ( empty() ) {
+        return;
     }
+
+    delete back();
+
+    pop_back();
 }
 
 Troop * Troops::GetTroop( size_t pos )
@@ -1306,26 +1310,6 @@ double Army::GetStrength() const
     return result;
 }
 
-double Army::getStrengthOfAverageStartingArmy( const Heroes * hero )
-{
-    assert( hero != nullptr );
-
-    const int race = hero->GetRace();
-
-    double result = 0.0;
-
-    for ( uint32_t dwelling : std::array<uint32_t, 2>{ DWELLING_MONSTER1, DWELLING_MONSTER2 } ) {
-        const Monster monster{ race, dwelling };
-        assert( monster.isValid() );
-
-        const auto [min, max] = getNumberOfMonstersInStartingArmy( monster );
-
-        result += Troop{ monster, ( min + max ) / 2 }.GetStrength();
-    }
-
-    return result;
-}
-
 void Army::Reset( const bool defaultArmy /* = false */ )
 {
     Troops::Clean();
