@@ -81,31 +81,32 @@ namespace
             troopTarget.SetCount( 2 );
         }
         else {
-            uint32_t freeSlots = static_cast<uint32_t>( 1 + armyTarget->Size() - armyTarget->GetOccupiedSlotCount() );
-
-            if ( isSameTroopType )
+            int32_t freeSlots = static_cast<int32_t>( 1 + armyTarget->Size() - armyTarget->GetOccupiedSlotCount() );
+            if ( isSameTroopType ) {
                 ++freeSlots;
+            }
 
-            const uint32_t maxCount = saveLastTroop ? troopFrom.GetCount() - 1 : troopFrom.GetCount();
-            uint32_t redistributeCount = isSameTroopType ? 1 : troopFrom.GetCount() / 2;
+            const int32_t maxCount = static_cast<int32_t>( saveLastTroop ? troopFrom.GetCount() - 1 : troopFrom.GetCount() );
+            int32_t redistributeCount = isSameTroopType ? 1 : static_cast<int32_t>( troopFrom.GetCount() ) / 2;
 
             bool useFastSplit = !isSameTroopType;
-            const uint32_t slots
-                = Dialog::ArmySplitTroop( ( freeSlots > overallCount ? overallCount : freeSlots ), maxCount, redistributeCount, useFastSplit, troopFrom.GetName() );
+            const int32_t slots = Dialog::ArmySplitTroop( ( freeSlots > static_cast<int32_t>( overallCount ) ? static_cast<int32_t>( overallCount ) : freeSlots ),
+                                                          maxCount, redistributeCount, useFastSplit, troopFrom.GetName() );
 
-            if ( slots < 2 || slots > 6 )
+            if ( slots < 2 || slots > 6 ) {
                 return;
+            }
 
             uint32_t totalSplitTroopCount = troopFrom.GetCount();
 
             if ( !useFastSplit && slots == 2 ) {
                 // this logic is used when splitting to a stack with the same unit
                 if ( isSameTroopType )
-                    troopTarget.SetCount( troopTarget.GetCount() + redistributeCount );
+                    troopTarget.SetCount( troopTarget.GetCount() + static_cast<uint32_t>( redistributeCount ) );
                 else
-                    troopTarget.Set( troopFrom, redistributeCount );
+                    troopTarget.Set( troopFrom, static_cast<uint32_t>( redistributeCount ) );
 
-                troopFrom.SetCount( totalSplitTroopCount - redistributeCount );
+                troopFrom.SetCount( totalSplitTroopCount - static_cast<uint32_t>( redistributeCount ) );
             }
             else {
                 if ( isSameTroopType )
@@ -480,10 +481,10 @@ bool ArmyBar::ActionBarLeftMouseSingleClick( ArmyTroop & troop )
                     fheroes2::renderMonsterFrame( mons, surface, { 6, 6 } );
                 }
 
-                uint32_t count = 1;
+                int32_t count = 1;
 
                 if ( Dialog::SelectCount( str, 1, 500000, count, 1, surface ) ) {
-                    troop.Set( mons, count );
+                    troop.Set( mons, static_cast<uint32_t>( count ) );
                 }
             }
         }
@@ -608,7 +609,7 @@ bool ArmyBar::ActionBarLeftMouseRelease( ArmyTroop & troop )
         return true;
     }
 
-    ArmyTroop * srcTroop = GetItem( LocalEvent::Get().GetMousePressLeft() );
+    ArmyTroop * srcTroop = GetItem( LocalEvent::Get().getMouseLeftButtonPressedPos() );
     if ( srcTroop == nullptr || !srcTroop->isValid() ) {
         return true;
     }
