@@ -102,17 +102,18 @@ enum building_t : uint32_t
     DWELLING_UPGRADES = DWELLING_UPGRADE2 | DWELLING_UPGRADE3 | DWELLING_UPGRADE4 | DWELLING_UPGRADE5 | DWELLING_UPGRADE6 | DWELLING_UPGRADE7
 };
 
-enum buildcond_t
+enum class BuildingStatus : int32_t
 {
-    NOT_TODAY = -1,
-    ALREADY_BUILT = -2,
-    NEED_CASTLE = -3,
-    BUILD_DISABLE = -4,
-    UNKNOWN_UPGRADE = -5,
-    REQUIRES_BUILD = -6,
-    LACK_RESOURCES = -7,
-    UNKNOWN_COND = 0,
-    ALLOW_BUILD = 1
+    UNKNOWN_COND,
+    ALLOW_BUILD,
+    NOT_TODAY,
+    ALREADY_BUILT,
+    NEED_CASTLE,
+    BUILD_DISABLE,
+    SHIPYARD_NOT_ALLOWED,
+    UNKNOWN_UPGRADE,
+    REQUIRES_BUILD,
+    LACK_RESOURCES
 };
 
 class Castle : public MapPosition, public BitModes, public ColorBase, public Control
@@ -120,9 +121,9 @@ class Castle : public MapPosition, public BitModes, public ColorBase, public Con
 public:
     enum : uint32_t
     {
-        ALLOWCASTLE = 0x00000002,
-        CUSTOMARMY = 0x00000004,
-        ALLOWBUILD = 0x00000008
+        UNUSED_ALLOW_CASTLE_CONSTRUCTION = ( 1 << 1 ),
+        CUSTOM_ARMY = ( 1 << 2 ),
+        ALLOW_TO_BUILD_TODAY = ( 1 << 3 )
     };
 
     enum class CastleDialogReturnValue : int
@@ -158,7 +159,7 @@ public:
 
     bool isCastle() const
     {
-        return ( building & BUILD_CASTLE ) != 0;
+        return ( _constructedBuildings & BUILD_CASTLE ) != 0;
     }
 
     bool HasSeaAccess() const;
@@ -202,7 +203,7 @@ public:
     bool isLibraryBuild() const;
     void MageGuildEducateHero( HeroBase & ) const;
 
-    bool isFortificationBuild() const;
+    bool isFortificationBuilt() const;
 
     const Army & GetArmy() const;
     Army & GetArmy();
@@ -238,10 +239,7 @@ public:
     void ChangeColor( int );
 
     void ActionNewDay();
-
     void ActionNewWeek();
-    void ActionNewWeekAIBonuses();
-
     void ActionNewMonth() const;
 
     void ActionPreBattle();
@@ -262,13 +260,13 @@ public:
 
     bool isBuild( uint32_t bd ) const
     {
-        return ( building & bd ) != 0;
+        return ( _constructedBuildings & bd ) != 0;
     }
 
     bool BuyBuilding( uint32_t );
 
-    int CheckBuyBuilding( const uint32_t build ) const;
-    static int GetAllBuildingStatus( const Castle & );
+    BuildingStatus CheckBuyBuilding( const uint32_t build ) const;
+    static BuildingStatus GetAllBuildingStatus( const Castle & );
 
     bool AllowBuyBoat( const bool checkPayment ) const;
     bool BuyBoat() const;
@@ -300,6 +298,11 @@ public:
 
     Troops getAvailableArmy( Funds potentialBudget ) const;
 
+    bool isBuildingDisabled( const uint32_t buildingType ) const
+    {
+        return ( _disabledBuildings & buildingType ) != 0;
+    }
+
 private:
     enum class ConstructionDialogResult : int
     {
@@ -339,13 +342,15 @@ private:
     friend StreamBase & operator>>( StreamBase &, Castle & );
 
     int race;
-    uint32_t building;
+    uint32_t _constructedBuildings;
+    uint32_t _disabledBuildings;
+
     Captain captain;
 
     std::string name;
 
     MageGuild mageguild;
-    uint32_t dwelling[CASTLEMAXMONSTER];
+    std::array<uint32_t, CASTLEMAXMONSTER> dwelling;
     Army army;
 };
 
@@ -416,9 +421,14 @@ namespace CastleDialog
 
 struct VecCastles : public std::vector<Castle *>
 {
-    Castle * GetFirstCastle() const;
+    VecCastles() = default;
+    VecCastles( const VecCastles & ) = delete;
 
-    void ChangeColors( int, int );
+    ~VecCastles() = default;
+
+    VecCastles & operator=( const VecCastles & ) = delete;
+
+    Castle * GetFirstCastle() const;
 };
 
 class AllCastles
@@ -457,11 +467,6 @@ public:
         std::for_each( _castles.begin(), _castles.end(), []( Castle * castle ) { castle->ActionNewWeek(); } );
     }
 
-    void NewWeekAI()
-    {
-        std::for_each( _castles.begin(), _castles.end(), []( Castle * castle ) { castle->ActionNewWeekAIBonuses(); } );
-    }
-
     void NewMonth()
     {
         std::for_each( _castles.begin(), _castles.end(), []( const Castle * castle ) { castle->ActionNewMonth(); } );
