@@ -1,6 +1,6 @@
 /***************************************************************************
  *   fheroes2: https://github.com/ihhub/fheroes2                           *
- *   Copyright (C) 2021 - 2023                                             *
+ *   Copyright (C) 2021 - 2024                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -18,10 +18,12 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#include "castle_building_info.h"
+
 #include <algorithm>
 #include <cassert>
+#include <cstdint>
 
-#include "castle_building_info.h"
 #include "maps_fileinfo.h"
 #include "race.h"
 #include "translations.h"
@@ -645,6 +647,46 @@ namespace
         return nullptr;
     }
 
+    const char * getRandomBuildingName( const building_t buildingId )
+    {
+        switch ( buildingId ) {
+        case BUILD_SPEC:
+            return _( "Special" );
+        case BUILD_WEL2:
+            return _( "Horde Building" );
+        case DWELLING_MONSTER1:
+            return _( "Dwelling 1" );
+        case DWELLING_MONSTER2:
+            return _( "Dwelling 2" );
+        case DWELLING_UPGRADE2:
+            return _( "Upg. Dwelling 2" );
+        case DWELLING_MONSTER3:
+            return _( "Dwelling 3" );
+        case DWELLING_UPGRADE3:
+            return _( "Upg. Dwelling 3" );
+        case DWELLING_MONSTER4:
+            return _( "Dwelling 4" );
+        case DWELLING_UPGRADE4:
+            return _( "Upg. Dwelling 4" );
+        case DWELLING_MONSTER5:
+            return _( "Dwelling 5" );
+        case DWELLING_UPGRADE5:
+            return _( "Upg. Dwelling 5" );
+        case DWELLING_MONSTER6:
+            return _( "Dwelling 6" );
+        case DWELLING_UPGRADE6:
+            return _( "Upg. Dwelling 6" );
+        case DWELLING_UPGRADE7:
+            return _( "2x Upg. Dwelling 6" );
+        default:
+            break;
+        }
+
+        // Did you add a new building?
+        assert( 0 );
+        return nullptr;
+    }
+
     const char * getKnightBuildingDescription( const building_t buildingId )
     {
         switch ( buildingId ) {
@@ -740,6 +782,22 @@ namespace
         assert( 0 );
         return nullptr;
     }
+
+    const char * getRandomBuildingDescription( const building_t buildingId )
+    {
+        switch ( buildingId ) {
+        case BUILD_SPEC:
+            return _( "The Special building gives a specific bonus to the chosen castle type." );
+        case BUILD_WEL2:
+            return _( "The Horde Building increases the growth rate of the level 1 creatures by 8 per week." );
+        default:
+            break;
+        }
+
+        // Did you add a new building?
+        assert( 0 );
+        return nullptr;
+    }
 }
 
 namespace fheroes2
@@ -834,6 +892,8 @@ namespace fheroes2
             return getWizardBuildingName( buildingId );
         case Race::NECR:
             return getNecromancerBuildingName( buildingId );
+        case Race::RAND:
+            return getRandomBuildingName( buildingId );
         default:
             break;
         }
@@ -902,6 +962,8 @@ namespace fheroes2
             return getWizardBuildingDescription( buildingId );
         case Race::NECR:
             return getNecromancerBuildingDescription( buildingId );
+        case Race::RAND:
+            return getRandomBuildingDescription( buildingId );
         default:
             break;
         }
@@ -912,6 +974,466 @@ namespace fheroes2
         return nullptr;
     }
 
+    building_t getUpgradeForBuilding( const int race, const building_t buildingId )
+    {
+        switch ( buildingId ) {
+        case BUILD_TENT:
+            return BUILD_CASTLE;
+        case BUILD_MAGEGUILD1:
+            return BUILD_MAGEGUILD2;
+        case BUILD_MAGEGUILD2:
+            return BUILD_MAGEGUILD3;
+        case BUILD_MAGEGUILD3:
+            return BUILD_MAGEGUILD4;
+        case BUILD_MAGEGUILD4:
+            return BUILD_MAGEGUILD5;
+        default:
+            break;
+        }
+
+        if ( race == Race::BARB ) {
+            switch ( buildingId ) {
+            case DWELLING_MONSTER2:
+                return DWELLING_UPGRADE2;
+            case DWELLING_MONSTER4:
+                return DWELLING_UPGRADE4;
+            case DWELLING_MONSTER5:
+                return DWELLING_UPGRADE5;
+            default:
+                break;
+            }
+        }
+        else if ( race == Race::KNGT ) {
+            switch ( buildingId ) {
+            case DWELLING_MONSTER2:
+                return DWELLING_UPGRADE2;
+            case DWELLING_MONSTER3:
+                return DWELLING_UPGRADE3;
+            case DWELLING_MONSTER4:
+                return DWELLING_UPGRADE4;
+            case DWELLING_MONSTER5:
+                return DWELLING_UPGRADE5;
+            case DWELLING_MONSTER6:
+                return DWELLING_UPGRADE6;
+            default:
+                break;
+            }
+        }
+        else if ( race == Race::NECR ) {
+            switch ( buildingId ) {
+            case DWELLING_MONSTER2:
+                return DWELLING_UPGRADE2;
+            case DWELLING_MONSTER3:
+                return DWELLING_UPGRADE3;
+            case DWELLING_MONSTER4:
+                return DWELLING_UPGRADE4;
+            case DWELLING_MONSTER5:
+                return DWELLING_UPGRADE5;
+            default:
+                break;
+            }
+        }
+        else if ( race == Race::SORC ) {
+            switch ( buildingId ) {
+            case DWELLING_MONSTER2:
+                return DWELLING_UPGRADE2;
+            case DWELLING_MONSTER3:
+                return DWELLING_UPGRADE3;
+            case DWELLING_MONSTER4:
+                return DWELLING_UPGRADE4;
+            default:
+                break;
+            }
+        }
+        else if ( race == Race::WRLK ) {
+            switch ( buildingId ) {
+            case DWELLING_MONSTER4:
+                return DWELLING_UPGRADE4;
+            case DWELLING_MONSTER6:
+                return DWELLING_UPGRADE6;
+            case DWELLING_UPGRADE6:
+                return DWELLING_UPGRADE7;
+            default:
+                break;
+            }
+        }
+        else if ( race == Race::WZRD ) {
+            switch ( buildingId ) {
+            case DWELLING_MONSTER3:
+                return DWELLING_UPGRADE3;
+            case DWELLING_MONSTER5:
+                return DWELLING_UPGRADE5;
+            case DWELLING_MONSTER6:
+                return DWELLING_UPGRADE6;
+            default:
+                break;
+            }
+        }
+        else if ( race == Race::RAND ) {
+            switch ( buildingId ) {
+            case DWELLING_MONSTER2:
+                return DWELLING_UPGRADE2;
+            case DWELLING_MONSTER3:
+                return DWELLING_UPGRADE3;
+            case DWELLING_MONSTER4:
+                return DWELLING_UPGRADE4;
+            case DWELLING_MONSTER5:
+                return DWELLING_UPGRADE5;
+            case DWELLING_MONSTER6:
+                return DWELLING_UPGRADE6;
+            case DWELLING_UPGRADE6:
+                return DWELLING_UPGRADE7;
+            default:
+                break;
+            }
+        }
+
+        return buildingId;
+    }
+
+    building_t getBuildingRequirement( const int race, const building_t building )
+    {
+        uint32_t requirement = 0;
+
+        switch ( building ) {
+        case BUILD_SPEC:
+            if ( race == Race::WZRD ) {
+                requirement |= BUILD_MAGEGUILD1;
+            }
+            break;
+
+        case DWELLING_MONSTER2:
+            switch ( race ) {
+            case Race::KNGT:
+            case Race::BARB:
+            case Race::WZRD:
+            case Race::WRLK:
+            case Race::NECR:
+                requirement |= DWELLING_MONSTER1;
+                break;
+
+            case Race::SORC:
+                requirement |= DWELLING_MONSTER1;
+                requirement |= BUILD_TAVERN;
+                break;
+
+            default:
+                break;
+            }
+            break;
+
+        case DWELLING_MONSTER3:
+            switch ( race ) {
+            case Race::KNGT:
+                requirement |= DWELLING_MONSTER1;
+                requirement |= BUILD_WELL;
+                break;
+
+            case Race::BARB:
+            case Race::SORC:
+            case Race::WZRD:
+            case Race::WRLK:
+            case Race::NECR:
+                requirement |= DWELLING_MONSTER1;
+                break;
+
+            default:
+                break;
+            }
+            break;
+
+        case DWELLING_MONSTER4:
+            switch ( race ) {
+            case Race::KNGT:
+                requirement |= DWELLING_MONSTER1;
+                requirement |= BUILD_TAVERN;
+                break;
+
+            case Race::BARB:
+                requirement |= DWELLING_MONSTER1;
+                break;
+
+            case Race::SORC:
+                requirement |= DWELLING_MONSTER3;
+                requirement |= BUILD_MAGEGUILD1;
+                break;
+
+            case Race::WZRD:
+            case Race::WRLK:
+                requirement |= DWELLING_MONSTER2;
+                break;
+
+            case Race::NECR:
+                requirement |= DWELLING_MONSTER3;
+                requirement |= BUILD_THIEVESGUILD;
+                break;
+
+            default:
+                break;
+            }
+            break;
+
+        case DWELLING_MONSTER5:
+            switch ( race ) {
+            case Race::KNGT:
+            case Race::BARB:
+                requirement |= DWELLING_MONSTER2;
+                requirement |= DWELLING_MONSTER3;
+                requirement |= DWELLING_MONSTER4;
+                break;
+
+            case Race::SORC:
+                requirement |= DWELLING_MONSTER4;
+                break;
+
+            case Race::WRLK:
+                requirement |= DWELLING_MONSTER3;
+                break;
+
+            case Race::WZRD:
+                requirement |= DWELLING_MONSTER3;
+                requirement |= BUILD_MAGEGUILD1;
+                break;
+
+            case Race::NECR:
+                requirement |= DWELLING_MONSTER2;
+                requirement |= BUILD_MAGEGUILD1;
+                break;
+
+            default:
+                break;
+            }
+            break;
+
+        case DWELLING_MONSTER6:
+            switch ( race ) {
+            case Race::KNGT:
+                requirement |= DWELLING_MONSTER2;
+                requirement |= DWELLING_MONSTER3;
+                requirement |= DWELLING_MONSTER4;
+                break;
+
+            case Race::BARB:
+            case Race::SORC:
+            case Race::NECR:
+                requirement |= DWELLING_MONSTER5;
+                break;
+
+            case Race::WRLK:
+            case Race::WZRD:
+                requirement |= DWELLING_MONSTER4;
+                requirement |= DWELLING_MONSTER5;
+                break;
+
+            default:
+                break;
+            }
+            break;
+
+        case DWELLING_UPGRADE2:
+            switch ( race ) {
+            case Race::KNGT:
+            case Race::BARB:
+                requirement |= DWELLING_MONSTER2;
+                requirement |= DWELLING_MONSTER3;
+                requirement |= DWELLING_MONSTER4;
+                break;
+
+            case Race::SORC:
+                requirement |= DWELLING_MONSTER2;
+                requirement |= BUILD_WELL;
+                break;
+
+            case Race::NECR:
+                requirement |= DWELLING_MONSTER2;
+                break;
+
+            default:
+                break;
+            }
+            break;
+
+        case DWELLING_UPGRADE3:
+            switch ( race ) {
+            case Race::KNGT:
+                requirement |= DWELLING_MONSTER2;
+                requirement |= DWELLING_MONSTER3;
+                requirement |= DWELLING_MONSTER4;
+                break;
+
+            case Race::SORC:
+                requirement |= DWELLING_MONSTER3;
+                requirement |= DWELLING_MONSTER4;
+                break;
+
+            case Race::WZRD:
+                requirement |= DWELLING_MONSTER3;
+                requirement |= BUILD_WELL;
+                break;
+
+            case Race::NECR:
+                requirement |= DWELLING_MONSTER3;
+                break;
+
+            default:
+                break;
+            }
+            break;
+
+        case DWELLING_UPGRADE4:
+            switch ( race ) {
+            case Race::KNGT:
+            case Race::BARB:
+                requirement |= DWELLING_MONSTER2;
+                requirement |= DWELLING_MONSTER3;
+                requirement |= DWELLING_MONSTER4;
+                break;
+
+            case Race::SORC:
+            case Race::WRLK:
+            case Race::NECR:
+                requirement |= DWELLING_MONSTER4;
+                break;
+
+            default:
+                break;
+            }
+            break;
+
+        case DWELLING_UPGRADE5:
+            switch ( race ) {
+            case Race::KNGT:
+            case Race::BARB:
+                requirement |= DWELLING_MONSTER5;
+                break;
+
+            case Race::WZRD:
+                requirement |= BUILD_SPEC;
+                requirement |= DWELLING_MONSTER5;
+                break;
+
+            case Race::NECR:
+                requirement |= BUILD_MAGEGUILD2;
+                requirement |= DWELLING_MONSTER5;
+                break;
+
+            default:
+                break;
+            }
+            break;
+
+        case DWELLING_UPGRADE6:
+            switch ( race ) {
+            case Race::KNGT:
+            case Race::WRLK:
+            case Race::WZRD:
+                requirement |= DWELLING_MONSTER6;
+                break;
+
+            default:
+                break;
+            }
+            break;
+        case DWELLING_UPGRADE7:
+            if ( race == Race::WRLK )
+                requirement |= DWELLING_UPGRADE6;
+            break;
+
+        default:
+            break;
+        }
+
+        return static_cast<building_t>( requirement );
+    }
+
+    std::string getBuildingRequirementString( const int race, const building_t building )
+    {
+        // prepare requirement build string
+        std::string requirement;
+        const uint32_t requirementBuildingIds = fheroes2::getBuildingRequirement( race, building );
+        const char sep = '\n';
+
+        for ( uint32_t itr = 0x00000001; itr; itr <<= 1 )
+            if ( requirementBuildingIds & itr ) {
+                requirement.append( Castle::GetStringBuilding( itr, race ) );
+                requirement += sep;
+            }
+
+        // Remove the last separator.
+        if ( !requirement.empty() ) {
+            requirement.pop_back();
+        }
+
+        return requirement;
+    }
+
+    int getIndexBuildingSprite( const building_t build )
+    {
+        switch ( build ) {
+        case DWELLING_MONSTER1:
+            return 19;
+        case DWELLING_MONSTER2:
+            return 20;
+        case DWELLING_MONSTER3:
+            return 21;
+        case DWELLING_MONSTER4:
+            return 22;
+        case DWELLING_MONSTER5:
+            return 23;
+        case DWELLING_MONSTER6:
+            return 24;
+        case DWELLING_UPGRADE2:
+            return 25;
+        case DWELLING_UPGRADE3:
+            return 26;
+        case DWELLING_UPGRADE4:
+            return 27;
+        case DWELLING_UPGRADE5:
+            return 28;
+        case DWELLING_UPGRADE6:
+            return 29;
+        case DWELLING_UPGRADE7:
+            return 30;
+        case BUILD_MAGEGUILD1:
+        case BUILD_MAGEGUILD2:
+        case BUILD_MAGEGUILD3:
+        case BUILD_MAGEGUILD4:
+        case BUILD_MAGEGUILD5:
+            return 0;
+        case BUILD_THIEVESGUILD:
+            return 1;
+        case BUILD_SHRINE:
+        case BUILD_TAVERN:
+            return 2;
+        case BUILD_SHIPYARD:
+            return 3;
+        case BUILD_WELL:
+            return 4;
+        case BUILD_CASTLE:
+            return 6;
+        case BUILD_STATUE:
+            return 7;
+        case BUILD_LEFTTURRET:
+            return 8;
+        case BUILD_RIGHTTURRET:
+            return 9;
+        case BUILD_MARKETPLACE:
+            return 10;
+        case BUILD_WEL2:
+            return 11;
+        case BUILD_MOAT:
+            return 12;
+        case BUILD_SPEC:
+            return 13;
+        case BUILD_CAPTAIN:
+            return 15;
+        default:
+            break;
+        }
+
+        return 0;
+    }
+
     std::vector<building_t> getBuildingDrawingPriorities( const int race, const GameVersion version )
     {
         std::vector<building_t> priorities;
