@@ -225,10 +225,10 @@ namespace
 
         LocalEvent & le = LocalEvent::Get();
         while ( le.HandleEvents() ) {
-            le.MousePressLeft( buttonOk.area() ) && buttonOk.isEnabled() ? buttonOk.drawOnPress() : buttonOk.drawOnRelease();
-            le.MousePressLeft( buttonCancel.area() ) ? buttonCancel.drawOnPress() : buttonCancel.drawOnRelease();
+            le.isMouseLeftButtonPressedInArea( buttonOk.area() ) && buttonOk.isEnabled() ? buttonOk.drawOnPress() : buttonOk.drawOnRelease();
+            le.isMouseLeftButtonPressedInArea( buttonCancel.area() ) ? buttonCancel.drawOnPress() : buttonCancel.drawOnRelease();
 
-            if ( le.MousePressRight( listRoi ) ) {
+            if ( le.isMouseRightButtonPressedInArea( listRoi ) ) {
                 continue;
             }
 
@@ -245,12 +245,12 @@ namespace
                 return false;
             }
 
-            if ( le.MousePressRight( buttonCancel.area() ) ) {
+            if ( le.isMouseRightButtonPressedInArea( buttonCancel.area() ) ) {
                 fheroes2::Text header( _( "Cancel" ), fheroes2::FontType::normalYellow() );
                 fheroes2::Text body( _( "Exit this menu without doing anything." ), fheroes2::FontType::normalWhite() );
                 fheroes2::showMessage( header, body, 0 );
             }
-            else if ( le.MousePressRight( buttonOk.area() ) ) {
+            else if ( le.isMouseRightButtonPressedInArea( buttonOk.area() ) ) {
                 fheroes2::Text header( _( "Okay" ), fheroes2::FontType::normalYellow() );
                 fheroes2::Text body( _( "Click to choose the selected language." ), fheroes2::FontType::normalWhite() );
                 fheroes2::showMessage( header, body, 0 );
