@@ -160,7 +160,7 @@ namespace
                 return true;
             }
 
-            if ( le.MousePressRight() ) {
+            if ( le.isMouseRightButtonPressed() ) {
                 const building_t building = _getBuildindTypeForRender();
                 std::string description = BuildingInfo::getBuildingDescription( _race, building );
                 const std::string requirement = fheroes2::getBuildingRequirementString( _race, building );
@@ -325,16 +325,20 @@ namespace Editor
         const fheroes2::Rect nameArea( dialogRoi.x + rightPartOffsetX, dialogRoi.y + 1, rightPartSizeX, statusBarSprite.height() - 2 );
         fheroes2::Copy( statusBarSprite, 17, 0, display, nameArea.x, dialogRoi.y, nameArea.width, statusBarSprite.height() );
 
+        const bool isTown = std::find( castleMetadata.builtBuildings.begin(), castleMetadata.builtBuildings.end(), BUILD_CASTLE ) == castleMetadata.builtBuildings.end();
+
         // Castle name text.
-        auto drawCastleName = [&castleMetadata, &display, &nameArea]() {
-            fheroes2::Text text( castleMetadata.customName.empty() ? _( "Random Castle Name" ) : castleMetadata.customName, fheroes2::FontType::normalWhite() );
+        auto drawCastleName = [&castleMetadata, &display, &nameArea, isTown]() {
+            fheroes2::Text text( castleMetadata.customName, fheroes2::FontType::normalWhite() );
+            if ( castleMetadata.customName.empty() ) {
+                text.set( isTown ? _( "Random Town Name" ) : _( "Random Castle Name" ), fheroes2::FontType::normalWhite() );
+            }
+
             text.fitToOneRow( nameArea.width );
             text.drawInRoi( nameArea.x + ( nameArea.width - text.width() ) / 2, nameArea.y + 2, display, nameArea );
         };
         drawCastleName();
 
-        const bool isTown = std::find( castleMetadata.builtBuildings.begin(), castleMetadata.builtBuildings.end(), BUILD_CASTLE ) == castleMetadata.builtBuildings.end();
-
         // Allow castle building checkbox.
         fheroes2::Point dstPt( dialogRoi.x + rightPartOffsetX + 10, dialogRoi.y + 130 );
         fheroes2::MovableSprite allowCastleSign;
@@ -355,15 +359,12 @@ namespace Editor
         const fheroes2::Rect defaultBuildingsArea = drawCheckboxWithText( defaultBuildingsSign, _( "Default Buildings" ), display, dstPt.x, dstPt.y, isEvilInterface );
         castleMetadata.customBuildings ? defaultBuildingsSign.hide() : defaultBuildingsSign.show();
 
-#if defined( RESTRICT_FEATURE )
-        // TODO: remove this macro definition check once the logic for building restriction is implemented.
         // Build restrict mode button.
         fheroes2::Button buttonRestrictBuilding( 0, 0, isEvilInterface ? ICN::BUTTON_RESTRICT_EVIL : ICN::BUTTON_RESTRICT_GOOD, 0, 1 );
         buttonRestrictBuilding.setPosition( dialogRoi.x + rightPartOffsetX + ( rightPartSizeX - buttonRestrictBuilding.area().width ) / 2, dialogRoi.y + 195 );
         const fheroes2::Rect buttonRestrictBuildingArea( buttonRestrictBuilding.area() );
         fheroes2::addGradientShadow( fheroes2::AGG::GetICN( ICN::BUTTON_RESTRICT_GOOD, 0 ), display, buttonRestrictBuildingArea.getPosition(), { -5, 5 } );
         buttonRestrictBuilding.draw();
-#endif
 
         const bool isNeutral = ( color == Color::NONE );
 
@@ -384,7 +385,7 @@ namespace Editor
         else {
             defaultArmySign.hide();
 
-            const fheroes2::Text armyText( _( "Castle Army" ), fheroes2::FontType::normalWhite() );
+            const fheroes2::Text armyText( isTown ? _( "Town Army" ) : _( "Castle Army" ), fheroes2::FontType::normalWhite() );
             armyText.drawInRoi( dialogRoi.x + rightPartOffsetX + ( rightPartSizeX - armyText.width() ) / 2, dstPt.y + 4, display, dialogRoi );
         }
 
@@ -467,21 +468,19 @@ namespace Editor
         bool buildingRestriction = false;
 
         while ( le.HandleEvents() ) {
-            buttonExit.drawOnState( le.MousePressLeft( buttonExitArea ) );
+            buttonExit.drawOnState( le.isMouseLeftButtonPressedInArea( buttonExitArea ) );
 
             if ( le.MouseClickLeft( buttonExitArea ) || Game::HotKeyCloseWindow() ) {
                 break;
             }
 
-#if defined( RESTRICT_FEATURE )
             if ( le.MouseClickLeft( buttonRestrictBuildingArea ) ) {
                 buildingRestriction = !buildingRestriction;
             }
 
-            buttonRestrictBuilding.drawOnState( buildingRestriction || le.MousePressLeft( buttonRestrictBuildingArea ) );
-#endif
+            buttonRestrictBuilding.drawOnState( buildingRestriction || le.isMouseLeftButtonPressedInArea( buttonRestrictBuildingArea ) );
 
-            if ( le.MouseCursor( nameArea ) ) {
+            if ( le.isMouseCursorPosInArea( nameArea ) ) {
                 message = _( "Click to change the Castle name. Right-click to reset to default." );
 
                 bool redrawName = false;
@@ -504,18 +503,18 @@ namespace Editor
                     display.render( nameArea );
                 }
             }
-            else if ( isTown && le.MouseCursor( allowCastleArea ) ) {
+            else if ( isTown && le.isMouseCursorPosInArea( allowCastleArea ) ) {
                 message = _( "Allow to build a castle in this town." );
 
                 if ( le.MouseClickLeft() ) {
                     allowCastleSign.isHidden() ? allowCastleSign.show() : allowCastleSign.hide();
                     display.render( allowCastleSign.getArea() );
                 }
-                else if ( le.MousePressRight() ) {
+                else if ( le.isMouseRightButtonPressed() ) {
                     fheroes2::showStandardTextMessage( _( "Allow Castle build" ), message, Dialog::ZERO );
                 }
             }
-            else if ( le.MouseCursor( defaultBuildingsArea ) ) {
+            else if ( le.isMouseCursorPosInArea( defaultBuildingsArea ) ) {
                 message = _( "Toggle the use of default buildings. Custom buildings will be reset!" );
 
                 if ( le.MouseClickLeft() ) {
@@ -539,22 +538,20 @@ namespace Editor
                         display.render( dialogRoi );
                     }
                 }
-                else if ( le.MousePressRight() ) {
+                else if ( le.isMouseRightButtonPressed() ) {
                     fheroes2::showStandardTextMessage( _( "Default Buildings" ), message, Dialog::ZERO );
                 }
             }
 
-#if defined( RESTRICT_FEATURE )
-            else if ( le.MouseCursor( buttonRestrictBuildingArea ) ) {
+            else if ( le.isMouseCursorPosInArea( buttonRestrictBuildingArea ) ) {
                 message = _( "Toggle building construction restriction mode." );
 
-                if ( le.MousePressRight() ) {
+                if ( le.isMouseRightButtonPressed() ) {
                     fheroes2::showStandardTextMessage( _( "Restrict Building Construction" ), message, Dialog::ZERO );
                 }
             }
-#endif
 
-            else if ( isNeutral && le.MouseCursor( defaultArmyArea ) ) {
+            else if ( isNeutral && le.isMouseCursorPosInArea( defaultArmyArea ) ) {
                 message = _( "Use default defenders army." );
 
                 if ( le.MouseClickLeft() ) {
@@ -569,11 +566,11 @@ namespace Editor
                         display.render( defaultArmySign.getArea() );
                     }
                 }
-                else if ( le.MousePressRight() ) {
+                else if ( le.isMouseRightButtonPressed() ) {
                     fheroes2::showStandardTextMessage( _( "Default Army" ), message, Dialog::ZERO );
                 }
             }
-            else if ( le.MouseCursor( armyBar.GetArea() ) ) {
+            else if ( le.isMouseCursorPosInArea( armyBar.GetArea() ) ) {
                 if ( armyBar.QueueEventProcessing( &message ) ) {
                     armyBar.Redraw( display );
 
@@ -585,16 +582,16 @@ namespace Editor
                     message = _( "Set custom Castle Army. Right-click to reset unit." );
                 }
             }
-            else if ( le.MouseCursor( buttonExitArea ) ) {
+            else if ( le.isMouseCursorPosInArea( buttonExitArea ) ) {
                 message = _( "Exit Castle Options" );
 
-                if ( le.MousePressRight() ) {
+                if ( le.isMouseRightButtonPressed() ) {
                     fheroes2::showStandardTextMessage( _( "Exit" ), message, Dialog::ZERO );
                 }
             }
             else {
                 for ( size_t i = 0; i < buildingsSize; ++i ) {
-                    if ( le.MouseCursor( buildings[i].getArea() ) ) {
+                    if ( le.isMouseCursorPosInArea( buildings[i].getArea() ) ) {
                         message = buildings[i].getSetStatusMessage();
 
                         if ( buildings[i].queueEventProcessing( buildingRestriction ) ) {
