@@ -93,7 +93,7 @@ namespace
         COUT( "Press " << Game::getHotKeyNameByEventId( Game::HotKeyEvent::MAIN_MENU_CREDITS ) << " to show Credits." )
         COUT( "Press " << Game::getHotKeyNameByEventId( Game::HotKeyEvent::MAIN_MENU_SETTINGS ) << " to open Game Settings." )
 
-        if ( Game::isPriceOfLoyaltyCampaignPresent() ) {
+        if ( Settings::Get().isPriceOfLoyaltySupported() ) {
             COUT( "Press " << Game::getHotKeyNameByEventId( Game::HotKeyEvent::EDITOR_MAIN_MENU ) << " to open Editor." )
         }
 
@@ -166,12 +166,18 @@ void Game::mainGameLoop( bool isFirstGameRun, bool isProbablyDemoVersion )
         case fheroes2::GameMode::LOAD_HOT_SEAT:
             result = Game::LoadHotseat();
             break;
-        case fheroes2::GameMode::SCENARIO_INFO:
-            result = Game::ScenarioInfo();
-            break;
-        case fheroes2::GameMode::SELECT_SCENARIO:
-            result = Game::SelectScenario();
+        case fheroes2::GameMode::SELECT_SCENARIO_ONE_HUMAN_PLAYER:
+        case fheroes2::GameMode::SELECT_SCENARIO_TWO_HUMAN_PLAYERS:
+        case fheroes2::GameMode::SELECT_SCENARIO_THREE_HUMAN_PLAYERS:
+        case fheroes2::GameMode::SELECT_SCENARIO_FOUR_HUMAN_PLAYERS:
+        case fheroes2::GameMode::SELECT_SCENARIO_FIVE_HUMAN_PLAYERS:
+        case fheroes2::GameMode::SELECT_SCENARIO_SIX_HUMAN_PLAYERS: {
+            const uint8_t humanPlayerCount
+                = static_cast<uint8_t>( static_cast<int>( result ) - static_cast<int>( fheroes2::GameMode::SELECT_SCENARIO_ONE_HUMAN_PLAYER ) );
+            // Add +1 since we don't have zero human player option.
+            result = Game::SelectScenario( humanPlayerCount + 1 );
             break;
+        }
         case fheroes2::GameMode::START_GAME:
             result = Game::StartGame();
             break;
@@ -302,7 +308,7 @@ fheroes2::GameMode Game::MainMenu( const bool isFirstGameRun )
 
     uint32_t lantern_frame = 0;
 
-    const bool isPOLPresent = Game::isPriceOfLoyaltyCampaignPresent();
+    const bool isPOLPresent = conf.isPriceOfLoyaltySupported();
 
     std::vector<ButtonInfo> buttons{ ButtonInfo{ NEWGAME_DEFAULT, buttonNewGame, false, false }, ButtonInfo{ LOADGAME_DEFAULT, buttonLoadGame, false, false },
                                      ButtonInfo{ HIGHSCORES_DEFAULT, buttonHighScores, false, false }, ButtonInfo{ CREDITS_DEFAULT, buttonCredits, false, false },
@@ -312,7 +318,7 @@ fheroes2::GameMode Game::MainMenu( const bool isFirstGameRun )
         buttons.emplace_back( ButtonInfo{ EDITOR_DEFAULT, buttonEditor, false, false } );
     }
 
-    for ( size_t i = 0; le.MouseMotion() && i < buttons.size(); ++i ) {
+    for ( size_t i = 0; le.hasMouseMoved() && i < buttons.size(); ++i ) {
         const fheroes2::Sprite & sprite = fheroes2::AGG::GetICN( ICN::BTNSHNGL, buttons[i].frame );
         fheroes2::Blit( sprite, display, sprite.x(), sprite.y() );
     }
@@ -335,14 +341,14 @@ fheroes2::GameMode Game::MainMenu( const bool isFirstGameRun )
         for ( size_t i = 0; i < buttons.size(); ++i ) {
             buttons[i].wasOver = buttons[i].isOver;
 
-            if ( le.MousePressLeft( buttons[i].button.area() ) ) {
+            if ( le.isMouseLeftButtonPressedInArea( buttons[i].button.area() ) ) {
                 buttons[i].button.drawOnPress();
             }
             else {
                 buttons[i].button.drawOnRelease();
             }
 
-            buttons[i].isOver = le.MouseCursor( buttons[i].button.area() );
+            buttons[i].isOver = le.isMouseCursorPosInArea( buttons[i].button.area() );
 
             if ( buttons[i].isOver != buttons[i].wasOver ) {
                 uint32_t frame = buttons[i].frame;
@@ -393,27 +399,27 @@ fheroes2::GameMode Game::MainMenu( const bool isFirstGameRun )
         }
 
         // right info
-        if ( le.MousePressRight( buttonQuit.area() ) )
+        if ( le.isMouseRightButtonPressedInArea( buttonQuit.area() ) )
             fheroes2::showStandardTextMessage( _( "Quit" ), _( "Quit Heroes of Might and Magic II and return to the operating system." ), Dialog::ZERO );
-        else if ( le.MousePressRight( buttonLoadGame.area() ) )
+        else if ( le.isMouseRightButtonPressedInArea( buttonLoadGame.area() ) )
             fheroes2::showStandardTextMessage( _( "Load Game" ), _( "Load a previously saved game." ), Dialog::ZERO );
-        else if ( le.MousePressRight( buttonCredits.area() ) )
+        else if ( le.isMouseRightButtonPressedInArea( buttonCredits.area() ) )
             fheroes2::showStandardTextMessage( _( "Credits" ), _( "View the credits screen." ), Dialog::ZERO );
-        else if ( le.MousePressRight( buttonHighScores.area() ) )
+        else if ( le.isMouseRightButtonPressedInArea( buttonHighScores.area() ) )
             fheroes2::showStandardTextMessage( _( "High Scores" ), _( "View the high scores screen." ), Dialog::ZERO );
-        else if ( le.MousePressRight( buttonNewGame.area() ) )
+        else if ( le.isMouseRightButtonPressedInArea( buttonNewGame.area() ) )
             fheroes2::showStandardTextMessage( _( "New Game" ), _( "Start a single or multi-player game." ), Dialog::ZERO );
-        else if ( isPOLPresent && le.MousePressRight( buttonEditor.area() ) ) {
+        else if ( isPOLPresent && le.isMouseRightButtonPressedInArea( buttonEditor.area() ) ) {
             fheroes2::showStandardTextMessage( _( "Editor" ), _( "Create new or modify existing maps." ), Dialog::ZERO );
         }
-        else if ( le.MousePressRight( settingsArea ) )
+        else if ( le.isMouseRightButtonPressedInArea( settingsArea ) )
             fheroes2::showStandardTextMessage( _( "Game Settings" ), _( "Change language, resolution and settings of the game." ), Dialog::ZERO );
 
         if ( validateAnimationDelay( MAIN_MENU_DELAY ) ) {
             const fheroes2::Sprite & lantern12 = fheroes2::AGG::GetICN( ICN::SHNGANIM, ICN::AnimationFrame( ICN::SHNGANIM, 0, lantern_frame ) );
             ++lantern_frame;
             fheroes2::Blit( lantern12, display, lantern12.x(), lantern12.y() );
-            if ( le.MouseCursor( settingsArea ) ) {
+            if ( le.isMouseCursorPosInArea( settingsArea ) ) {
                 const int32_t doorOffsetY = static_cast<int32_t>( 55 * scale ) + offsetY;
                 fheroes2::Blit( highlightDoor, 0, doorOffsetY, display, highlightDoor.x(), highlightDoor.y() + doorOffsetY, highlightDoor.width(),
                                 highlightDoor.height() );
