@@ -151,103 +151,11 @@ namespace
         return false;
     }
 
-    bool isShadowSprite( const MP2::ObjectIcnType objectIcnType, const uint8_t icnIndex )
-    {
-        return isValidShadowSprite( MP2::getIcnIdFromObjectIcnType( objectIcnType ), icnIndex );
-    }
-
     bool isValidReefsSprite( const MP2::ObjectIcnType objectIcnType, const uint8_t icnIndex )
     {
         return objectIcnType == MP2::OBJ_ICN_TYPE_X_LOC2 && ObjXlc2::isReefs( icnIndex );
     }
 
-#if defined( VERIFY_SHADOW_SPRITES )
-    // Define VERIFY_SHADOW_SPRITES macro to be able to use these functions.
-    bool isShadowImage( const fheroes2::Image & image )
-    {
-        // The image can't be empty and must have transform layer.
-        assert( !image.empty() && !image.singleLayer() );
-        if ( image.empty() )
-            return false;
-
-        const uint8_t * data = image.transform();
-        const uint8_t * dataEnd = data + image.width() * image.height();
-
-        size_t transformCounter = 0;
-
-        for ( ; data != dataEnd; ++data ) {
-            if ( *data == 0 ) {
-                return false;
-            }
-            else if ( *data != 1 ) {
-                ++transformCounter;
-            }
-        }
-
-        if ( transformCounter == 0 ) {
-            assert( image.width() == 1 && image.height() == 1 );
-            return true;
-        }
-
-        return true;
-    }
-
-    // Use this function to verify the correctness of data being returned by isValidShadowSprite function.
-    void findAllShadowImages()
-    {
-        static bool completed = false;
-        if ( completed ) {
-            return;
-        }
-
-        const std::vector<int32_t> icnIds
-            = { ICN::MTNDSRT,  ICN::MTNGRAS,  ICN::MTNLAVA,  ICN::MTNMULT,  ICN::MTNSNOW,  ICN::MTNSWMP,  ICN::MTNCRCK,  ICN::MTNDIRT,  ICN::TREDECI,
-                ICN::TREEVIL,  ICN::TREFALL,  ICN::TREFIR,   ICN::TREJNGL,  ICN::TRESNOW,  ICN::OBJNCRCK, ICN::OBJNDIRT, ICN::OBJNDSRT, ICN::OBJNGRA2,
-                ICN::OBJNGRAS, ICN::OBJNMUL2, ICN::OBJNMULT, ICN::OBJNSNOW, ICN::OBJNSWMP, ICN::OBJNWAT2, ICN::OBJNWATR, ICN::OBJNARTI, ICN::OBJNRSRC,
-                ICN::OBJNTWRD, ICN::OBJNTWSH, ICN::STREAM,   ICN::OBJNTWBA, ICN::ROAD,     ICN::EXTRAOVR, ICN::X_LOC1,   ICN::X_LOC2,   ICN::X_LOC3,
-                ICN::OBJNTOWN, ICN::OBJNLAVA, ICN::OBJNLAV2, ICN::OBJNLAV3, ICN::MONS32 };
-
-        for ( const int32_t icnId : icnIds ) {
-            const uint32_t maxIndex = fheroes2::AGG::GetICNCount( icnId );
-            assert( maxIndex != 0 );
-
-            std::string output;
-
-            for ( uint32_t i = 0; i < maxIndex; i++ ) {
-                const uint32_t startIndex = ICN::AnimationFrame( icnId, i, 0, true );
-                const bool hasAnimation = startIndex != 0;
-                bool isImageShadow = isShadowImage( fheroes2::AGG::GetICN( icnId, i ) );
-                if ( isImageShadow && hasAnimation ) {
-                    for ( uint32_t indexOffset = 1;; ++indexOffset ) {
-                        const uint32_t animationIndex = ICN::AnimationFrame( icnId, i, indexOffset, true );
-                        if ( startIndex == animationIndex ) {
-                            break;
-                        }
-
-                        if ( !isShadowImage( fheroes2::AGG::GetICN( icnId, animationIndex ) ) ) {
-                            isImageShadow = false;
-                            break;
-                        }
-                    }
-                }
-
-                if ( isValidShadowSprite( icnId, i ) != isImageShadow ) {
-                    output += std::to_string( i );
-                    output += ", ";
-                }
-            }
-
-            if ( output.empty() ) {
-                continue;
-            }
-
-            VERBOSE_LOG( ICN::GetString( icnId ) << ": " << output )
-        }
-
-        completed = true;
-    }
-#endif
-
     bool isShortObject( const MP2::MapObjectType objectType )
     {
         // Some objects allow middle moves even being attached to the bottom.
@@ -441,7 +349,7 @@ namespace
 
     bool isAddonShadow( const Maps::TilesAddon & ta )
     {
-        return isShadowSprite( ta._objectIcnType, ta._imageIndex );
+        return isValidShadowSprite( MP2::getIcnIdFromObjectIcnType( ta._objectIcnType ), ta._imageIndex );
     }
 
     bool isAddonResource( const Maps::TilesAddon & ta )
@@ -533,15 +441,10 @@ void Maps::Tiles::setTerrain( const uint16_t terrainImageIndex, const bool horiz
     _terrainFlags = ( verticalFlip ? 1 : 0 ) + ( horizontalFlip ? 2 : 0 );
 
     const int newGround = Ground::getGroundByImageIndex( terrainImageIndex );
-    const bool isNewGroundWater = ( newGround == Ground::WATER );
-    const int oldGround = GetGround();
 
-    if ( ( isNewGroundWater || oldGround == Ground::WATER ) && oldGround != newGround ) {
-        // When changing water to land and vice-versa we should remove all objects from the tile.
-        eraseOjects( *this, ObjectErasureType::ALL_OBJECTS );
-    }
+    // TODO: Remove all objects from map when changing water to land and vice-versa in both 'Map_Format' and 'tiles'.
 
-    if ( ( _isTileMarkedAsRoad || isStream() ) && !isNewGroundWater && Maps::Ground::doesTerrainImageIndexContainEmbeddedObjects( terrainImageIndex ) ) {
+    if ( ( _isTileMarkedAsRoad || isStream() ) && ( newGround != Ground::WATER ) && Maps::Ground::doesTerrainImageIndexContainEmbeddedObjects( terrainImageIndex ) ) {
         // There cannot be extra objects under the roads and streams.
         _terrainImageIndex = Ground::getRandomTerrainImageIndex( Ground::getGroundByImageIndex( terrainImageIndex ), false );
 
@@ -695,7 +598,7 @@ int Maps::Tiles::getOriginalPassability() const
 {
     const MP2::MapObjectType objectType = GetObject( false );
 
-    if ( MP2::isActionObject( objectType ) ) {
+    if ( MP2::isOffGameActionObject( objectType ) ) {
         return MP2::getActionObjectDirection( objectType );
     }
 
@@ -734,7 +637,8 @@ void Maps::Tiles::updatePassability()
     // Get object type but ignore heroes as they are "temporary" objects.
     const MP2::MapObjectType objectType = GetObject( false );
 
-    if ( !MP2::isActionObject( objectType ) && ( _mainAddon._objectIcnType != MP2::OBJ_ICN_TYPE_UNKNOWN ) && !_mainAddon.isPassabilityTransparent() && !isShadow() ) {
+    if ( !MP2::isOffGameActionObject( objectType ) && ( _mainAddon._objectIcnType != MP2::OBJ_ICN_TYPE_UNKNOWN ) && !_mainAddon.isPassabilityTransparent()
+         && !isShadow() ) {
         // This is a non-action object.
 
         if ( !Maps::isValidDirection( _index, Direction::BOTTOM ) ) {
@@ -790,7 +694,7 @@ void Maps::Tiles::updatePassability()
             const MP2::MapObjectType bottomTileObjectType = bottomTile.GetObject( false );
             const MP2::MapObjectType correctedObjectType = MP2::getBaseActionObjectType( bottomTileObjectType );
 
-            if ( MP2::isActionObject( bottomTileObjectType ) ) {
+            if ( MP2::isOffGameActionObject( bottomTileObjectType ) ) {
                 if ( ( MP2::getActionObjectDirection( bottomTileObjectType ) & Direction::TOP ) == 0 ) {
                     if ( isShortObject( bottomTileObjectType ) ) {
                         _tilePassabilityDirections &= ~Direction::BOTTOM;
@@ -801,7 +705,7 @@ void Maps::Tiles::updatePassability()
                     }
                 }
             }
-            else if ( bottomTile._mainObjectType != MP2::OBJ_NONE && correctedObjectType != bottomTileObjectType && MP2::isActionObject( correctedObjectType )
+            else if ( bottomTile._mainObjectType != MP2::OBJ_NONE && correctedObjectType != bottomTileObjectType && MP2::isOffGameActionObject( correctedObjectType )
                       && isShortObject( correctedObjectType ) && ( bottomTile.getOriginalPassability() & Direction::TOP ) == 0 ) {
                 _tilePassabilityDirections &= ~Direction::BOTTOM;
             }
@@ -1313,7 +1217,7 @@ void Maps::Tiles::_updateRoadFlag()
     }
 }
 
-void Maps::Tiles::fixTileObjectType( Tiles & tile )
+void Maps::Tiles::fixMP2MapTileObjectType( Tiles & tile )
 {
     const MP2::MapObjectType originalObjectType = tile.GetObject( false );
 
@@ -1869,12 +1773,21 @@ StreamBase & Maps::operator>>( StreamBase & msg, Tiles & tile )
     msg >> tile._mainAddon._imageIndex;
 
     using MainObjectTypeUnderlyingType = std::underlying_type_t<decltype( tile._mainObjectType )>;
-    static_assert( std::is_same_v<MainObjectTypeUnderlyingType, uint8_t>, "Type of _mainObjectType has been changed, check the logic below" );
+    static_assert( std::is_same_v<MainObjectTypeUnderlyingType, uint16_t>, "Type of _mainObjectType has been changed, check the logic below" );
 
-    MainObjectTypeUnderlyingType mainObjectType = MP2::OBJ_NONE;
-    msg >> mainObjectType;
+    static_assert( LAST_SUPPORTED_FORMAT_VERSION < FORMAT_VERSION_PRE3_1100_RELEASE, "Remove the logic below." );
+    if ( Game::GetVersionOfCurrentSaveFile() < FORMAT_VERSION_PRE3_1100_RELEASE ) {
+        uint8_t mainObjectType = static_cast<uint8_t>( MP2::OBJ_NONE );
+        msg >> mainObjectType;
 
-    tile._mainObjectType = static_cast<MP2::MapObjectType>( mainObjectType );
+        tile._mainObjectType = static_cast<MP2::MapObjectType>( mainObjectType );
+    }
+    else {
+        MainObjectTypeUnderlyingType mainObjectType = MP2::OBJ_NONE;
+        msg >> mainObjectType;
+
+        tile._mainObjectType = static_cast<MP2::MapObjectType>( mainObjectType );
+    }
 
     return msg >> tile._fogColors >> tile._metadata >> tile._occupantHeroId >> tile._isTileMarkedAsRoad >> tile._addonBottomLayer >> tile._addonTopLayer
            >> tile._mainAddon._layerType >> tile._boatOwnerColor;
