@@ -27,6 +27,7 @@
 #include <sstream>
 
 #include "artifact.h"
+#include "game_static.h"
 #include "spell.h"
 #include "tools.h"
 #include "translations.h"
@@ -476,11 +477,18 @@ namespace
               {},
               {} },
 
-            // Magic Book cannot be located on a map.
-            { gettext_noop( "Magic Book" ), gettext_noop( "The %{name} enables the hero to cast spells." ), nullptr, {}, {} },
+            // Magic Book cannot be located on the original map. The Resurrection map format allows to place it on the map.
+            { gettext_noop( "Magic Book" ),
+              gettext_noop( "The %{name} enables the hero to cast spells." ),
+              gettext_noop(
+                  "A young man approaches you: \"My Lord, allow me to show you my latest invention for spreading knowledge!\" You follow the man into his workshop and immediately observe a large apparatus with levers and cranks. \"This here is it!\" he says eagerly, \"The Printing Press.\" And before you get to say a word, he hands you a Magic Book." ),
+              {},
+              {} },
 
-            // These are artifacts used only for map editor (?).
-            { gettext_noop( "Dummy 1" ), gettext_noop( "The reserved artifact." ), nullptr, {}, {} },
+            // This artifact is only used in Editor for the special victory conditions.
+            { gettext_noop( "Ultimate Artifact" ), gettext_noop( "Victory can be achieved by finding any Ultimate Artifact." ), nullptr, {}, {} },
+
+            // These are artifacts used only for original map editor (?).
             { gettext_noop( "Dummy 2" ), gettext_noop( "The reserved artifact." ), nullptr, {}, {} },
             { gettext_noop( "Dummy 3" ), gettext_noop( "The reserved artifact." ), nullptr, {}, {} },
             { gettext_noop( "Dummy 4" ), gettext_noop( "The reserved artifact." ), nullptr, {}, {} },
@@ -540,19 +548,19 @@ namespace
                   "You spy a gleaming object poking up out of the ground. You send a member of your party over to investigate. He comes back with a golden helmet in his hands. You realize that it must be the helmet of the legendary Anduran, the only man who was known to wear solid gold armor." ),
               {},
               {} },
-            { gettext_noop( "Holy Hammer" ),
-              gettext_noop( "The %{name} increases the hero's attack skill by %{count}." ),
-              gettext_noop(
-                  "You come upon a battle where a Paladin has been mortally wounded by a group of Zombies. He asks you to take his hammer and finish what he started. As you pick it up, it begins to hum, and then everything becomes a blur. The Zombies lie dead, the hammer dripping with blood. You strap it to your belt." ),
-              {},
-              {} },
+            { gettext_noop( "Holy Hammer" ), gettext_noop( "The %{name} increases the hero's attack skill by %{count}." ), gettext_noop( "You come upon a battle where a Paladin has been mortally wounded by a group of Zombies. He asks you to take his hammer and finish what he started. As you pick it up, it begins to hum, and then everything becomes a blur. The Zombies lie dead, the hammer dripping with blood. You strap it to your belt." ), {}, {} },
             { gettext_noop( "Legendary Scepter" ),
               gettext_noop( "The %{name} adds %{count} points to all attributes." ),
               gettext_noop(
                   "Upon cresting a small hill, you come upon a ridiculous looking sight. A Sprite is attempting to carry a Scepter that is almost as big as it is. Trying not to laugh, you ask, \"Need help?\" The Sprite glares at you and answers: \"You think this is funny? Fine. You can carry it. I much prefer flying anyway.\"" ),
               {},
               {} },
-            { gettext_noop( "Masthead" ), gettext_noop( "The %{name} boosts the hero's troops' luck and morale by %{count} each in sea combat." ), gettext_noop( "An old seaman tells you a tale of an enchanted masthead that he used in his youth to rally his crew during times of trouble. He then hands you a faded map that shows where he hid it. After much exploring, you find it stashed underneath a nearby dock." ), {}, {} },
+            { gettext_noop( "Masthead" ),
+              gettext_noop( "The %{name} boosts the hero's troops' luck and morale by %{count} each in sea combat." ),
+              gettext_noop(
+                  "An old seaman tells you a tale of an enchanted masthead that he used in his youth to rally his crew during times of trouble. He then hands you a faded map that shows where he hid it. After much exploring, you find it stashed underneath a nearby dock." ),
+              {},
+              {} },
             { gettext_noop( "Sphere of Negation" ),
               gettext_noop( "The %{name} disables all spell casting, for both sides, in combat." ),
               gettext_noop(
@@ -722,7 +730,7 @@ namespace
 
         artifactData[Artifact::WAND_NEGATION].bonuses.emplace_back( fheroes2::ArtifactBonusType::DISPEL_SPELL_IMMUNITY );
 
-        artifactData[Artifact::GOLDEN_BOW].bonuses.emplace_back( fheroes2::ArtifactBonusType::NO_SHOOTING_PENALTY, 50 );
+        artifactData[Artifact::GOLDEN_BOW].bonuses.emplace_back( fheroes2::ArtifactBonusType::NO_SHOOTING_PENALTY, GameStatic::getCastleWallRangedPenalty() );
 
         artifactData[Artifact::TELESCOPE].bonuses.emplace_back( fheroes2::ArtifactBonusType::AREA_REVEAL_DISTANCE, 1 );
 
@@ -763,7 +771,7 @@ namespace
         artifactData[Artifact::BLACK_PEARL].bonuses.emplace_back( fheroes2::ArtifactBonusType::SPELL_POWER_SKILL, 2 );
 
         artifactData[Artifact::MAGIC_BOOK].bonuses.emplace_back( fheroes2::ArtifactBonusType::NONE );
-        artifactData[Artifact::UNUSED_83].bonuses.emplace_back( fheroes2::ArtifactBonusType::NONE );
+        artifactData[Artifact::EDITOR_ANY_ULTIMATE_ARTIFACT].bonuses.emplace_back( fheroes2::ArtifactBonusType::NONE );
         artifactData[Artifact::UNUSED_84].bonuses.emplace_back( fheroes2::ArtifactBonusType::NONE );
         artifactData[Artifact::UNUSED_85].bonuses.emplace_back( fheroes2::ArtifactBonusType::NONE );
         artifactData[Artifact::UNUSED_86].bonuses.emplace_back( fheroes2::ArtifactBonusType::NONE );
