@@ -34,9 +34,11 @@
 #include "cursor.h"
 #include "difficulty.h"
 #include "game.h"
+#include "game_io.h"
 #include "gamedefs.h"
 #include "logging.h"
 #include "render_processor.h"
+#include "save_format_version.h"
 #include "screen.h"
 #include "serialize.h"
 #include "settings.h"
@@ -108,7 +110,6 @@ Settings::Settings()
     , scroll_speed( SCROLL_SPEED_NORMAL )
     , battle_speed( DEFAULT_BATTLE_SPEED )
     , game_type( 0 )
-    , preferably_count_players( 0 )
 {
     _gameOptions.SetModes( GAME_FIRST_RUN );
     _gameOptions.SetModes( GAME_SHOW_INTRO );
@@ -500,8 +501,6 @@ void Settings::SetCurrentFileInfo( Maps::FileInfo fi )
     current_maps_file = std::move( fi );
 
     players.Init( current_maps_file );
-
-    preferably_count_players = 0;
 }
 
 bool Settings::setGameLanguage( const std::string & language )
@@ -1005,11 +1004,6 @@ void Settings::SetMusicVolume( int v )
     music_volume = std::clamp( v, 0, 10 );
 }
 
-void Settings::SetPreferablyCountPlayers( int c )
-{
-    preferably_count_players = std::min( c, 6 );
-}
-
 bool Settings::isCampaignGameType() const
 {
     return ( game_type & Game::TYPE_CAMPAIGN ) != 0;
@@ -1094,10 +1088,18 @@ void Settings::resetFirstGameRun()
 
 StreamBase & operator<<( StreamBase & msg, const Settings & conf )
 {
-    return msg << conf._gameLanguage << conf.current_maps_file << conf._gameDifficulty << conf.game_type << conf.preferably_count_players << conf.players;
+    return msg << conf._gameLanguage << conf.current_maps_file << conf._gameDifficulty << conf.game_type << conf.players;
 }
 
 StreamBase & operator>>( StreamBase & msg, Settings & conf )
 {
-    return msg >> conf._loadedFileLanguage >> conf.current_maps_file >> conf._gameDifficulty >> conf.game_type >> conf.preferably_count_players >> conf.players;
+    msg >> conf._loadedFileLanguage >> conf.current_maps_file >> conf._gameDifficulty >> conf.game_type;
+
+    static_assert( LAST_SUPPORTED_FORMAT_VERSION < FORMAT_VERSION_PRE1_1101_RELEASE, "Remove the logic below." );
+    if ( Game::GetVersionOfCurrentSaveFile() < FORMAT_VERSION_PRE1_1101_RELEASE ) {
+        int temp;
+        msg >> temp;
+    }
+
+    return msg >> conf.players;
 }
